pilot.api.compute.api.PilotComputeService

Package pilot :: Package api :: Package compute :: Module api :: Class PilotComputeService |

# Class PilotComputeService

source code

PilotComputeService (PCS).

The PilotComputeService is responsible for creating and managing the PilotComputes.

It is the application's interface to the Pilot-Manager in the P* Model.

Instance Methods
__init__(self, pjs_id=None) Create a PilotComputeService object. | source code
cancel(self) Cancel the PilotComputeService. | source code
create_pilot(self, rm, pilotcompute_description, pj_type=None, context=None) Add a PilotCompute to the PilotComputeService | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| id
| pilot_jobs
| state
Inherited from `object`: `__class__`

Method Details

### __init__(self, pjs_id=None) (Constructor) | source code
Create a PilotComputeService object. Keyword arguments: pjs_id -- Don't create a new, but connect to an existing (optional) Overrides: object.__init__

### cancel(self) | source code
Cancel the PilotComputeService. This also cancels all the PilotJobs that were under control of this PJS. Keyword arguments: None Return value: Result of operation

### create_pilot(self, rm, pilotcompute_description, pj_type=None, context=None) | source code
Add a PilotCompute to the PilotComputeService Keyword arguments: rm -- Contact string for the resource manager pilotcompute_description -- PilotCompute Description pj_type -- backend type (optional) context -- Security context (optional) Return value: A PilotCompute handle